#!/usr/bin/python3
import boto3
import json
from ast import literal_eval
from termcolor import colored
from .common import run_lambda

# Containers to display
containers = (
    'platform-',
    'ec-',
    'wd-'
)


def status_color(status):
    if status == 'running':
        return('green')
    elif status == 'waiting':
        return('yellow')
    else:
        return('red')


def run_status(args):

    if args.environment:
        print('Fetching status...\n')
        get_status(args)

    return


def get_status(args):
    env = args.environment
    verbose = args.verbose
    if verbose:
        columnWidth = 27
    else:
        columnWidth = 24

    result = []

    response = run_lambda('paas-tools-lambda_get-status', {
        'environment': env
    })

    header = 'Instance Name'.ljust(columnWidth)
    header += 'Image'.ljust(columnWidth)
    header += 'Status'
    if verbose:
        header += ' (UTC)'
    header += '\n'

    print(colored(header, attrs=['bold']))

    try:
        for pod in response['status']:
            if pod['instance_name'].startswith(containers):

                # Instance name
                if verbose:
                    line = pod['instance_name'].ljust(columnWidth)
                else:
                    line = pod['instance_name'].split('-')[0]\
                        .ljust(columnWidth)

                # Image name and version
                line += pod['image'].split('/')[-1].ljust(columnWidth)

                # Status and timestamp
                line += colored(
                    pod['status'].capitalize().ljust(11),
                    status_color(pod['status']))
                if verbose:
                    line += pod['timeStamp']
                print(line)

    except KeyError as e:
        print('Unable to get status, please try again')

    print()
    return



#!/usr/bin/python3
import boto3
from termcolor import colored
from time import sleep
from .common import run_lambda, SpinCursor, poll_build, get_log_stream


def run_build(args):

    if args.no_ec:
        ec = False
    else:
        ec = True

    if args.version:
        print('Triggering build...\n')
        trigger_build(args.version, ec)

    return


def trigger_build(version, ec):
    # Trigger codebuild and return result
    build_response = run_lambda('paas-tools-lambda_post-build',
                                {'build': 'paas-platform-build',
                                 'version': version[0],
                                 'ec': str(ec)})

    if 'error' in build_response:
        print(colored(build_response['error'], 'red'))
        return
    else:
        buildId = build_response['buildId']

    sleep(3)
    status = poll_build(buildId)

    print(colored('Building platform, version: "'
          + version[0] + '"...', attrs=['bold']))

    spin = SpinCursor(msg='  Building...\t')
    spin.start()

    while True:
        sleep(5)
        status = poll_build(buildId)
        failedStates = [
            'FAILED',
            'FAULT',
            'TIMED_OUT',
            'STOPPED'
        ]
        if status['buildStatus'] == 'SUCCEEDED':
            spin.stop()
            spin.join()
            print(colored('\n  Build successfull!\n', 'green'))
            fetch_log(buildId)

            print(colored('To deploy a new version run "mztools deploy"\n',
                          attrs=['dark']))

            break
        elif status['buildStatus'] in failedStates:
            spin.stop()
            spin.join()
            print(colored('\n  Build failed!\n', 'red'))
            fetch_log(buildId)
            break

    return


def fetch_log(buildId):
    print(colored('  Fetching logs', attrs=['bold']))
    print('    Waiting for log stream to close...30', end='', flush=True)
    seconds = 30
    while seconds > 0:
        sleep(1)
        if seconds == 20:
            print('...20', end='', flush=True)
        if seconds == 10:
            print('...10', end='', flush=True)
        seconds -= 1

    print('...done')
    print('    Fetching log stream...', end='', flush=True)
    logEvents = get_log_stream('/aws/codebuild/paas-platform-build')
    fileName = buildId.split(':', maxsplit=1)[1] + '.log'
    with open(fileName, 'w') as logFile:
        for line in logEvents:
            logFile.write(line + '\n')
    print('done')
    print('    Please see log: "' + fileName + '"\n')



#!/usr/bin/python3
import boto3
import json
from termcolor import colored
from .common import run_lambda, get_log_stream


def run_log(args):

    if args.environment:
        print('Fetching log...\n')
        get_log(args)

    return


def get_log(args):
    env = args.environment
    if args.json:
        pretty = False
    else:
        pretty = True

    logGroup = '/' + env + '/cluster'

    logEvents = get_log_stream(
        logGroup,
        prefix='kubernetes.var.log.containers.platform'
        )

    fileName = env + '-platform.log'
    with open(fileName, 'w') as logFile:
        for line in logEvents:
            splitLine = line.split(' - ', 1)
            if pretty:
                dictLine = json.loads(splitLine[1])
                print(splitLine[0] + ' : ' + dictLine['log'].rstrip())
            else:
                logFile.write(splitLine[1] + '\n')

        if not pretty:
            print(colored('  Please see log: "' + fileName + '"\n', 'green'))



#!/usr/bin/python3
from termcolor import colored
from .common import get_file_list


def run_list(args):
    print('Fetching files...\n')

    argsList = []

    if args:
        if args.config:
            argsList.append('configs')
        if args.extref:
            argsList.append('extrefs')
        if args.file:
            argsList.append('files')
        if args.python_module:
            argsList.append('python-modules')
        if args.python_requirement:
            argsList.append('python-requirements')
        if args.backup:
            argsList.append('backups')
    else:
        argsList.extend([
            'configs',
            'extrefs',
            'files',
            'python-modules',
            'python-requirements',
            'backups'
        ])

    list_files(argsList)

    return


def list_files(argsList):
    '''List files currently in bucket'''

    # Get files
    files = get_file_list(argsList)

    name_col_width = 40
    size_col_width = 15
    modified_col_width = 20

    # Print header
    header = 'Name:'.ljust(name_col_width)
    header += '  Size:'.ljust(size_col_width)
    header += '  Last modified:'.ljust(modified_col_width)
    print('  ' + colored(header, attrs=['bold']))

    # Print files
    for fileType in argsList:
        if len(files[fileType]) > 0:
            print(colored('\n  ' + fileType.capitalize() + ':',
                  attrs=['bold']))
            for f in files[fileType]:
                name = f['name']

                if name:
                    lineName = '    ' + name.ljust(name_col_width)
                    lineSize = f['size'].ljust(size_col_width)
                    lineModified = f['modified'].ljust(modified_col_width)

                    # If filename is too long, add a new line
                    if len(name) > 40:
                        print(lineName)
                        print(
                            ''.ljust(name_col_width + 4)
                            + lineSize + lineModified)
                    else:
                        print(lineName + lineSize + lineModified)

    print(colored('\n  To build a new container run "mztools build"\n',
                  attrs=['dark']))

    return()



#!/usr/bin/python3
import boto3
import json
from termcolor import colored
from .common import get_repo_bucket, get_general_bucket
from .common import get_files, get_file_list


def run_get(args):

    print('Getting files...\n')

    # if args.package:
    #     get_files(bucket, args.package, prefix='packages')
    if args.config:
        if '-' in args.config:
            args.config = get_all_files(get_repo_bucket(), 'configs')

        get_files(get_repo_bucket(), args.config, prefix='configs')
    # if args.script:
    #     get_files(bucket, args.script, prefix='scripts')
    if args.extref:
        if '-' in args.extref:
            args.extref = get_all_files(get_repo_bucket(), 'extrefs')

        get_files(get_repo_bucket(), args.extref, prefix='extrefs')
    if args.file:
        if '-' in args.file:
            args.file = get_all_files(get_general_bucket(), 'files')

        get_files(get_general_bucket(), args.file, prefix='files')
    if args.python_module:
        if '-' in args.python_module:
            args.python_module = get_all_files(get_repo_bucket(), 'python-modules')

        get_files(get_repo_bucket(), args.python_module, prefix='python-modules')
    if args.python_requirement:
        if '-' in args.python_requirement:
            args.python_requirement = get_all_files(get_repo_bucket(), 'python-requirements')

        get_files(get_repo_bucket(), args.python_requirement,
                  prefix='python-requirements')

    print(colored('\n  To list files run "mztools list"\n',
                  attrs=['dark']))

    return


def get_all_files(bucket, type):

    files = []

    # Get files from repo bucket
    if type is not 'files':
        # Get only extrefs
        prefixList = [type]

        filesDict = get_file_list(prefixList)
    else:
        filesDict = get_file_list()

    if len(filesDict[type]) > 0:
        for f in filesDict[type]:
            files.append(f['name'])
    return files



#!/usr/bin/python3

from termcolor import colored
from .common import get_parameter


def run_info(args):
    print(colored('Company: ',
          'white', attrs=['bold']) + get_parameter('/customer/name'))
    print('')

    print(colored('Platform versions: ',
          'white', attrs=['bold']))

    print('')

    print('Dev:  ' + get_parameter('/dev/platform/version'))
    print('Test: ' + get_parameter('/test/platform/version'))
    print('Prod: ' + get_parameter('/prod/platform/version'))

    print('')

    print(colored('EC versions: ',
          'white', attrs=['bold']))

    print('')

    print('Dev:  ' + get_parameter('/dev/ec/version'))
    print('Test: ' + get_parameter('/test/ec/version'))
    print('Prod: ' + get_parameter('/prod/ec/version'))

    return



#!/usr/bin/python3
# coding=utf-8

import json
import threading
import sys
import os
import time
import shutil
import tempfile

import boto3
import botocore

from datetime import datetime
from termcolor import colored
from .ver import __version__


class SpinCursor(threading.Thread):
    """ A console spin cursor class """

    def __init__(self, msg='', speed=2):
        # Count of a spin
        self.count = 0
        self.out = sys.stdout
        self.flag = False
        # Any message to print first ?
        self.msg = msg
        # Complete printed string
        self.string = ''
        # Speed is given as number of spins a second
        # Use it to calculate spin wait time
        self.waittime = 1.0/float(speed*4)
        try:
            if os.environ["PYTHONIOENCODING"] == 'utf-8':
                self.spinchars = ("◴", "◷", "◶", "◵")
        except KeyError:
            self.spinchars = ('- ', '\ ', '| ', '/ ')

        threading.Thread.__init__(self, None, None, "Spin Thread")

    def spin(self):
        """ Perform a single spin """

        for x in self.spinchars:
            self.string = self.msg + x + "\r"
            self.out.write(self.string)
            self.out.flush()
            time.sleep(self.waittime)

    def run(self):

        while not self.flag:
            self.spin()
            self.count += 1

        # Clean up display...
        self.out.write(" "*(len(self.string) + 1))

    def stop(self):
        self.flag = True


def poll_build(buildid):
    # Poll AWS CLI for status of build/deploy
    response = run_lambda('paas-tools-lambda_get-build', {
        'buildid': buildid
    })

    return(json.loads(response))


def get_bucket_name(ssmParam):
    try:
        ssmClient = boto3.client('ssm')
        response = ssmClient.get_parameter(
            Name=ssmParam,
            WithDecryption=False
        )
    except botocore.exceptions.ClientError as e:
        print('Not allowed to read from cloud, have you assumed the correct role?')
        print('AWS Error: ', e)
        sys.exit(1)

    return(response['Parameter']['Value'])


def get_repo_bucket():
    return(get_bucket_name('tools-bucket'))


def get_extrefs_bucket():
    return(get_bucket_name('extrefs-bucket'))


def get_general_bucket():
    return(get_bucket_name('paas-general-bucket'))


def check_response_version(response):

    # Do we have an incompatible string in the response?
    if 'mztools_version' in response:
        resp = json.loads(response)
        print('Not allowed to trigger backend, mztools is out of date.')
        print('Current version: ' + __version__)
        print('Required version: ' + resp['mztools_version'])
        sys.exit(1)

    # We return  if "mztools_version" is not in the response
    return

def run_lambda(function, payload={}):
    # Append mztools version
    payload['mztools_version'] = __version__

    try:
        lmb = boto3.client('lambda')
        response = lmb.invoke(
            FunctionName=function,
            InvocationType='RequestResponse',
            LogType='Tail',
            Payload=json.dumps(payload)
        )
    except botocore.exceptions.PartialCredentialsError as e:
        print('Not allowed to trigger backend, have you assumed the correct role?')
        print('AWS Error: ', e)
        sys.exit(1)

    # Load the response, decoded with json
    json_response = json.loads(response['Payload'].read().decode("utf-8"))

    # Check for invalid version first
    check_response_version(json_response)

    return json_response


def get_log_stream(logGroup, prefix=None):
    client = boto3.client('logs')

    # Get last log stream or prefixed log stream
    if prefix:
        successfulFetch = False
        nextToken = ''
        while not successfulFetch:
            if nextToken != '':
                response = client.describe_log_streams(
                    logGroupName=logGroup,
                    orderBy='LastEventTime',
                    nextToken=nextToken,
                    descending=True,
                    limit=50
                )
            else:
                response = client.describe_log_streams(
                    logGroupName=logGroup,
                    orderBy='LastEventTime',
                    descending=True,
                    limit=50
                )

            for log in response['logStreams']:
                if log['logStreamName'].startswith(prefix):
                    response['logStreams'][0] = log
                    successfulFetch = True
                    break
                else:
                    nextToken = response['nextToken']

    else:
        response = client.describe_log_streams(
            logGroupName=logGroup,
            orderBy='LastEventTime',
            descending=True,
            limit=1
        )

    try:
        logStream = response['logStreams'][0]['logStreamName']
    except IndexError:
        print(colored('  Log not found!\n', 'red'))
        return()

    # Get log events
    response = client.get_log_events(
        logGroupName=logGroup,
        logStreamName=logStream,
        startFromHead=False
        )

    # Add all formatted lines to a list of lines
    logEvents = []
    for event in response['events']:
        timeStamp = datetime.fromtimestamp(event['timestamp']/1000.0)\
            .strftime('%c')
        logEvents.append("{} - {}".format(
            timeStamp,
            event['message'].rstrip('\n')
            )
        )

    return(logEvents)


def get_file_list(prefixList=None):
    # Invoke list lambda to get current uploaded files
    filesDict = run_lambda(
        'paas-tools-lambda_get-list',
        {'prefix': prefixList}
    )

    return(filesDict)


def put_files(bucket, files, prefix):
    s3 = boto3.resource('s3')

    print(colored('  ' + prefix.capitalize() + ':', attrs=['bold']))

    for fileName in files:
        print('    ' + fileName, end='')
        data = open(fileName, 'rb')
        fileNameNoPath = fileName.split('/')[-1]
        if prefix == 'files':
            key = fileNameNoPath
        else:
            key = 'repo/' + prefix + '/' + fileNameNoPath
        try:
            s3.Bucket(bucket).put_object(Key=key, Body=data)
            print(colored('\tok', 'green'))
        except botocore.exceptions.ClientError as e:
            print(colored('\tfailed', 'red'))

    return


def put_folder(bucket, folders, prefix):
    tempDir = tempfile.gettempdir()

    for folder in folders:
        fileName = tempDir + '/' + folder.split('/')[-1]
        shutil.make_archive(fileName, 'zip', folder)
        put_files(bucket, [fileName + '.zip'], prefix)

    return


def get_files(bucket, files, prefix):
    s3 = boto3.resource('s3')

    print(colored('  ' + prefix.capitalize() + ':', attrs=['bold']))

    for fileName in files:
        print('    ' + fileName, end='')
        if prefix is 'files' or prefix is 'backups':
            key = fileName
        else:
            key = 'repo/' + prefix + '/' + fileName
        try:
            s3.Bucket(bucket).download_file(key, fileName)
            print(colored('\tok', 'green'))
        except botocore.exceptions.ClientError as e:
            print(colored('\tfailed', 'red'))

    return


def delete_files(filesToDelete):
    # Bool to keep track of if we have any files to delete
    staged = False

    # Verify/stage files
    stagedFilesToDelete = run_delete_operation(filesToDelete)

    # List all files, staged or not found
    for fileType in stagedFilesToDelete:
        print(colored('  ' + fileType.capitalize() + ':', attrs=['bold']))
        try:
            if stagedFilesToDelete[fileType]['files']:
                staged = True
                print('    Staged for deletion:')
                for f in stagedFilesToDelete[fileType]['files']:
                    print(colored('      ' + f, 'yellow'))
        except KeyError:
            pass

        try:
            if stagedFilesToDelete[fileType]['notfound']:
                print('    Not found:')
                for f in stagedFilesToDelete[fileType]['notfound']:
                    print(colored('      ' + f, 'red'))
        except KeyError:
            pass

        print('')

    # If we have files to delete, ask the question
    if staged:
        question = 'Are you sure you want to delete these files? '
        question += '[yes/no]: '
        verification = input(question)
        while verification != 'yes':
            if verification == 'no':
                sys.exit(0)
            print('Please answer "yes" or "no"')
            verification = input(question)

        print('Deleting files...\n')

        # Delete the actual files
        actualFilesToDelete = run_delete_operation(filesToDelete, True)

        for fileType in actualFilesToDelete:
            print(colored('  ' + fileType.capitalize() + ':', attrs=['bold']))
            try:
                if actualFilesToDelete[fileType]['files']:
                    print('    Deleted:')
                    for f in actualFilesToDelete[fileType]['files']:
                        print(colored('      ' + f, 'green'))
            except KeyError:
                pass

            try:
                if actualFilesToDelete[fileType]['notfound']:
                    print('    Not deleted:')
                    for f in actualFilesToDelete[fileType]['notfound']:
                        print(colored('      ' + f, 'red'))
            except KeyError:
                pass
    else:
        print('Nothing to delete\n')
        return

    return


def get_parameter(param):
    try:
        ssmClient = boto3.client('ssm')
        response = ssmClient.get_parameter(
            Name=param,
            WithDecryption=False
        )['Parameter']['Value']
        return response
    except botocore.exceptions.ClientError:
        return '-'

def run_delete_operation(filesDict, verified=False):

    filesOperated = {}

    for fileType in filesDict:
        # Update dict with what files to delete
        response = run_lambda('paas-tools-lambda_post-delete', {
            'bucket': filesDict[fileType]['bucket'],
            'prefix': filesDict[fileType]['prefix'],
            'files': filesDict[fileType]['files'],
            'verified': verified
            })

        filesOperated[fileType] = response

    return(filesOperated)



#!/usr/bin/python3
import boto3
import json
import sys
from termcolor import colored
from .common import run_lambda, get_repo_bucket, get_general_bucket, delete_files


def run_delete(args):
    print('Checking files...\n')

    filesToDelete = {}
    repoBucket = get_repo_bucket()
    generalBucket = get_general_bucket()

    if args.config:
        filesToDelete['configs'] = {
            'bucket': repoBucket,
            'files': args.config,
            'prefix': 'repo/configs'
        }
    if args.extref:
        filesToDelete['extrefs'] = {
            'bucket': repoBucket,
            'files': args.extref,
            'prefix': 'repo/extrefs'
        }
    if args.file:
        filesToDelete['files'] = {
            'bucket': generalBucket,
            'files': args.file,
            'prefix': ''
        }
    if args.python_module:
        filesToDelete['python-modules'] = {
            'bucket': repoBucket,
            'files': args.python_module,
            'prefix': 'repo/python-modules'
        }
    if args.python_requirement:
        filesToDelete['python-requirements'] = {
            'bucket': repoBucket,
            'files': args.python_requirement,
            'prefix': 'repo/python-requirements'
        }

    delete_files(filesToDelete)

    print(colored('\nTo list files run "mztools list"\n',
                  attrs=['dark']))

    return



#!/usr/bin/python3
import boto3
import json
from termcolor import colored
from .common import run_lambda


def run_version():
    print('Fetching versions...\n')
    list_version()

    return


def list_version():
    '''List versions running in test & prod
    as well as what is ready to deploy'''

    filesDict = run_lambda('paas-tools-lambda_get-versions')

    print(colored('  Current version in:', attrs=['bold']))
    print('    Production:   ' + filesDict['current_prod_version'])
    print('    Test:         ' + filesDict['current_test_version'])
    print('    Dev:          ' + filesDict['current_dev_version'])
    print(colored('\n  Available:', attrs=['bold']))
    for version in filesDict['available']:
        print('    ' + version)

    print(colored('\n  To deploy a new version run "mztools deploy"\n',
                  attrs=['dark']))

    return()



#!/usr/bin/python3
import boto3
import json
import sys
from time import sleep
from termcolor import colored
from .common import run_lambda, SpinCursor, poll_build, get_parameter


def run_deploy(args):
    if args.no_ec:
        ec = False
    else:
        ec = True

    if args.test:
        if check_version(args.test[0], 'test'):
            print('You are trying to deploy the same version again.')
            print('Please pick another version to deploy.')
            return

        print('Triggering deploy...\n')
        deploy_container(ec, 'test', args.test[0])
    if args.promote:
        if check_version(get_parameter('/test/platform/version'), 'prod'):
            print('You are trying to deploy the same version again.')
            print('Deploy a another version to test for the ability to promote.')
            return

        question = '\nAre you sure you want to promote test to production? '
        question += '[yes/no]: '
        verification = input(question)
        while verification != 'yes':
            if verification == 'no':
                sys.exit(0)
            print('Please answer "yes" or "no"')
            verification = input(question)

        print('Promoting test to production...\n')
        deploy_container(ec, 'prod')
    if args.dev:
        if check_version(args.dev[0], 'dev'):
            print('You are trying to deploy the same version again.')
            print('Please pick another version to deploy.')
            return

        if args.reset:
            reset = True
            print(colored(
                '\nThis will wipe all data in dev and deploy version: {}.'
                .format(args.dev[0]),
                attrs=['bold']
                )
            )
            question = '\nAre you sure you want to reset the dev env? '
            question += '[yes/no]: '
            verification = input(question)
            while verification != 'yes':
                if verification == 'no':
                    sys.exit(0)
                print('Please answer "yes" or "no"')
                verification = input(question)

            print('Resetting dev with version {}...\n'.format(args.dev[0]))
        else:
            reset = False

        deploy_container(ec, 'dev', args.dev[0], reset)

    return


def check_version(version, env):
    # Check that the version we are trying to deploy is not the same as
    # the one that is already deployed
    if version == get_parameter('/' + env + '/platform/version'):
        print('Trying to deploy: ' + version)
        print('Version in ' + env + ': ' + version)
        return True
    return False

def deploy_container(ec, environment=None, version=None, reset=False):

    if environment == 'prod':
        msg = 'Promoting test to prod...'
    else:
        msg = 'Deploying ' + version + ' to ' + environment + '...'

    print(colored('\n  ' + msg, attrs=['bold']))

    response = run_lambda('paas-tools-lambda_post-deploy', {
        'version': version,
        'env': environment,
        'ec': ec,
        'reset': reset
    })

    try:
        print('    Platform'.ljust(20), end='')
        if response['platform']['Status'] == "Failed":
            print(colored('Failed!', 'red', attrs=['bold']))
        elif response['platform']['Status'] == "Success":
            print(colored('OK', 'green', attrs=['bold']))
    except KeyError:
        print(colored('Unknown', 'yellow', attrs=['bold']))

    if ec:
        try:
            print('    EC'.ljust(20), end='')
            if response['ec']['Status'] == "Failed":
                print(colored('Failed!', 'red', attrs=['bold']))
            elif response['ec']['Status'] == "Success":
                print(colored('OK', 'green', attrs=['bold']))
        except KeyError:
            print(colored('Unknown', 'yellow', attrs=['bold']))

    print('')

    if environment == 'test':
        print(colored('  To promote test to prod run "mztools deploy -p"\n',
                      attrs=['dark']))

    return



#!/usr/bin/python3
import boto3
import json
from termcolor import colored
from .common import get_repo_bucket, get_general_bucket, put_files, put_folder


def run_put(args):
    print('Putting files...\n')

    # if args.package:
    #     put_files(bucket, args.package, prefix='packages')
    if args.config:
        put_files(get_repo_bucket(), args.config, prefix='configs')
    # if args.script:
    #     put_files(bucket, args.script, prefix='scripts')
    if args.extref:
        put_files(get_repo_bucket(), args.extref, prefix='extrefs')
        print(colored('\nExtrefs are located in /extrefs after you build your image.', attrs=['dark']))
    if args.file:
        put_files(get_general_bucket(), args.file, prefix='files')
    if args.python_module:
        put_folder(get_repo_bucket(), args.python_module, prefix='python-modules')
    if args.python_requirement:
        put_files(get_repo_bucket(), args.python_requirement,
                  prefix='python-requirements')

    print(colored('\nTo list files run "mztools list"\n',
                  attrs=['dark']))

    return



#!/usr/bin/python3
from .common import run_lambda

def run_restart(args):

    if args.environment:
        print('Initiating restart trigger...\n')

        env = args.environment
        name = args.name

        res = run_lambda('paas-tools-lambda_restart-pico', {
            'environment': env,
            'name': name
        })

    print(res)
    print('\nUse the status command to get info about the state of the picos.\n')
    return



from setuptools import setup

exec(open('mztools/ver.py').read())

with open('README.md') as file:
    long_description = file.read()

setup(name='mztools',
      version=__version__,
      description='Digital Route PaaS CLI',
      author='Digital Route',
      author_email='aws-paas@digitalroute.com',
      long_description=long_description,
      license='MIT',
      url='https://github.com/digitalroute/mztools',
      packages=['mztools'],
      scripts=['bin/mztools'],
      zip_safe=False,
      install_requires=[
        "boto3",
        "termcolor",
      ],
      )
